@@ -7,10 +7,15 @@
 @Version :   1.0
 @Contact :   gitopen@gmail.com
 @License :   (C)Copyright 2021-2022
-@Desc    :   用于快捷导入常用的包
+@Desc    :   用于快捷导入常用的包，注意这个文件不要格式化！
 """
 
-__version__ = "0.2.2"
+__version__ = "0.2.3"
+
+
+###################################
+注意！！这个文件不要格式化！！！
+###################################
 
 
 # ## 精简编程时的麻烦，常用的其他包的导入
@@ -19,7 +24,7 @@ import matplotlib.pyplot as plt
 from matplotlib.axes import Axes
 from matplotlib.figure import Figure
 
-# ##gitopenlib 本身的包的导入
+# ## gitopenlib 本身的包的导入
 from gitopenlib.helpers import mongo as gm
 from gitopenlib.indicators import diversity as gd
 from gitopenlib.indicators import statistics as gs
@@ -28,3 +33,14 @@ from gitopenlib.utils import files as gf
 from gitopenlib.utils import others as go
 from gitopenlib.utils import plot as gp
 from gitopenlib.utils import wonders as gw
+
+# ## 其他常用的包
+import os
+import time
+import sys
+from collections import defaultdict
+
+# ## 科学计算常用包
+import pandas as pd
+from pandas import DataFrame, Series
+import numpy as np
